clc
clear all
close all

%% Import data from selected file
%fid=fopen('NTNU-134-2014-03-17_03-44-47.csv');
fid=fopen('K:\vindauto\NTNU141M-2013-05-13_11-50-00.csv')
%s-string, d-integer, f-float
aks='%d%s%d%f%f%f'; %Accelerometer
anem='%d%s%d%f%f%f%f%d%f%f%f%f'; %Anemometer
str=['%s%s%s' aks aks anem];
C =textscan(fid,str,'delimiter',',');
Wind_polar_raw=[C{19} C{20} C{21}];
%% Remove false values
t_raw=(0:size(Wind_polar_raw,1)-1)*1/200;
Wind_polar=zeros(size(Wind_polar_raw,1)/20,3);
t=zeros(size(Wind_polar_raw,1)/20,1);
for n=1:size(Wind_polar_raw,1)/20
    tmp=Wind_polar_raw(20*n-19:20*n,:);
    Wind_polar(n,:)=mean(tmp(tmp(:,1)<500,:),1);
    t(n,1)=mean(t_raw(20*n-19:20*n));
    if isnan(Wind_polar(n,:))
        Wind_polar(n,:)=Wind_polar(n-1,:);
        disp(['Missing values n= ' num2str(n) '  t=' num2str(round(t(n,1)))])
    end
end
%% Plot time series
figure
subplot(3,1,1)
plot(t_raw,Wind_polar_raw(:,1),'--','Color',[0.8 0.8 0.8])
hold on
plot(t,Wind_polar(:,1))
ylim([0 360])

subplot(3,1,2)
plot(t_raw,Wind_polar_raw(:,2),'Color',[0.8 0.8 0.8])
hold on
plot(t,Wind_polar(:,2))
ylim([0 40])

subplot(3,1,3)
plot(t_raw,Wind_polar_raw(:,3),'Color',[0.8 0.8 0.8])
hold on
plot(t,Wind_polar(:,3))
ylim([-10 10])
%% Select data range
disp('Select data range')
[xo yo]=ginput(2);
Wind_polar=Wind_polar(t>xo(1,1) & t<xo(2,1),:);
t=t(t>xo(1,1) & t<xo(2,1));
%% Plot selected data
t=t-t(1,1);
figure
subplot(3,1,1)
plot(t,Wind_polar(:,1))
ylim([0 360])

subplot(3,1,2)
plot(t,Wind_polar(:,2))
ylim([0 40])

subplot(3,1,3)
plot(t,Wind_polar(:,3))
ylim([-10 10])
%% Transform to cartesian coordinate system
mean_dir=mean(Wind_polar(:,1));
phi=(Wind_polar(:,1)-mean_dir)*2*pi/360;
Wind_cartesian(:,1)=Wind_polar(:,2).*cos(phi);
Wind_cartesian(:,2)=Wind_polar(:,2).*sin(phi);
Wind_cartesian(:,3)=Wind_polar(:,3);
%% Plot time series and fitted normal distribution
V=mean(Wind_cartesian(:,1));
Iu=std(Wind_cartesian(:,1))/V;
Iv=std(Wind_cartesian(:,2))/V;
Iw=std(Wind_cartesian(:,3))/V;
figure
subplot(3,2,1)
plot(t,Wind_cartesian(:,1))
ylim([0 30])
title(['Mean Wind V=' num2str(1/10*round(V*10)) ' I_u=' num2str(1/100*round(Iu*100))])
subplot(3,2,3)
plot(t,Wind_cartesian(:,2))
ylim([-10 10])
title(['I_v=' num2str(1/100*round(Iv*100))])
subplot(3,2,5)
plot(t,Wind_cartesian(:,3))
ylim([-10 10])
title(['I_w=' num2str(1/100*round(Iw*100))])
subplot(3,2,2)
histfit(Wind_cartesian(:,1))
subplot(3,2,4)
histfit(Wind_cartesian(:,2))
subplot(3,2,6)
histfit(Wind_cartesian(:,3))
%% Estimate spectra using FFT
figure
Fs=1/(t(2)-t(1));
for n=1:3
    [X(n,:),freq(n,:)]=positiveFFT(Wind_cartesian(:,n).',Fs);
    Spectra(n,:)=X(n,:).*conj(X(n,:))/(2*2*pi*(freq(n,2)-freq(n,1)));
    subplot(2,3,n)
    loglog(2*pi*freq,Spectra(n,:))
    hold on
    loglog(2*pi*freq(1,:),0.1*(2*pi*freq(1,:)).^(-5/3),'k')
end
%% Estimate spectra using welch
N=size(Wind_cartesian,1);                             % Number of elements in the vectors
Fs=1/(t(2)-t(1));                                     % Sampling frequency
nfft=1*N;  
Hs=spectrum.welch('Hamming',N/10,50);
figure
for n=1:size(Wind_cartesian,2)
    h=psd(Hs,Wind_cartesian(:,n)-mean(Wind_cartesian(:,n)),'NFFT',nfft,'Fs',Fs);
    fakse=2*pi*h.Frequencies;
    Spectra_welch(:,n)=1/(2*pi)*h.Data;
    subplot(2,3,n)
    loglog(2*pi*h.Frequencies,Spectra_welch(:,n))
end




